@@ -12,7 +12,8 @@ enum {
 
 enum { 
   APP_LP_FILE_ENCODING = END_OF_APP_BPS, APP_LP_EDIT_FONT_SIZE, APP_LP_EDIT_HEIGHT,
-  APP_LP_SCREEN_WIDTH, APP_LP_SCREEN_HEIGHT, END_OF_APP_LPS
+  APP_LP_EDIT_WIDTH, 
+  APP_LP_SCREEN_WIDTH, APP_LP_SCREEN_HEIGHT, APP_LP_SCREEN_WIDTH_H, APP_LP_SCREEN_HEIGHT_H, APP_LP_STYLE, APP_LP_DOCK_STYLE, END_OF_APP_LPS
 };
 
 enum {
