@@ -190,6 +190,7 @@ void CCanvas::DrawRectangle(int x1, int y1, int x2, int y2, int Color, int iOutl
   if(bFill) {
     SET_COLOR(Color);
 #if WITH_CAIRO
+    cairo_set_line_width(cr, iThickness);
     cairo_rectangle(cr, x1, y1, x2-x1+1.0, y2-y1+1.0);
     cairo_fill(cr);
 #else
@@ -204,6 +205,7 @@ void CCanvas::DrawRectangle(int x1, int y1, int x2, int y2, int Color, int iOutl
       SET_COLOR(iOutlineColour);
     
 #if WITH_CAIRO
+    cairo_set_line_width(cr, iThickness);
     cairo_rectangle(cr, x1+.5, y1+.5, x2-x1, y2-y1);
     cairo_stroke(cr);
 #else
@@ -214,6 +216,28 @@ void CCanvas::DrawRectangle(int x1, int y1, int x2, int y2, int Color, int iOutl
   END_DRAWING;
 }
 
+void CCanvas::DrawCircle(screenint iCX, screenint iCY, screenint iR, int iColour, bool bFill) {
+#if WITH_CAIRO
+#else
+  GdkGC *graphics_context;
+  GdkColormap *colormap;
+
+  graphics_context = m_pCanvas->style->fg_gc[GTK_WIDGET_STATE(m_pCanvas)];
+  colormap = gdk_colormap_get_system();
+#endif
+
+  BEGIN_DRAWING;
+  SET_COLOR(iColour);
+
+#if WITH_CAIRO
+  cairo_arc(cr, iCX, iCY, iR, 0, 2*M_PI);
+#else
+  // FIXME
+#endif
+
+  END_DRAWING;
+}
+
 void CCanvas::Polygon(Dasher::CDasherScreen::point *Points, int Number, int Colour, int iWidth) {
 
   if(iWidth == 1) // This is to make it work propely on Windows
@@ -258,11 +282,11 @@ void CCanvas::Polyline(Dasher::CDasherScreen::point *Points, int Number, int iWi
 
   // FIXME - combine this with polygon?
 
+#if WITH_CAIRO
+#else
   if(iWidth == 1) // This is to make it work propely on Windows
     iWidth = 0; 
 
-#if WITH_CAIRO
-#else
   GdkGC *graphics_context;
   GdkColormap *colormap;
   
@@ -274,6 +298,7 @@ void CCanvas::Polyline(Dasher::CDasherScreen::point *Points, int Number, int iWi
   SET_COLOR(Colour);
 
 #if WITH_CAIRO
+  cairo_set_line_width(cr, iWidth);
   cairo_move_to(cr, Points[0].x+.5, Points[0].y+.5);
   for (int i=1; i < Number; i++)
     cairo_line_to(cr, Points[i].x+.5, Points[i].y+.5);
@@ -365,8 +390,6 @@ bool CCanvas::ExposeEvent(GtkWidget *pWidget, GdkEventExpose *pEvent) {
   return true;
 }
 
-
-
 void CCanvas::SetColourScheme(const Dasher::CCustomColours *Colours) {
   int iNumColours(Colours->GetNumColours());
 
