@@ -2,12 +2,8 @@
 
 #include "Menu.h"
 #include "dasher.h"
-#include "edit.h"
 #include "DasherTypes.h"
-#include "fileops.h"
-
 #include "GtkDasherControl.h"
-#include "AppSettings.h"
 
 #include <glib/gi18n.h>
 #ifdef GNOME_LIBS
@@ -28,10 +24,6 @@ extern GtkWidget *window;
 extern GtkWidget *file_selector;
 
 void PopulateMenus(GladeXML *pGladeWidgets) {
-
-  gtk_check_menu_item_set_active( GTK_CHECK_MENU_ITEM(glade_xml_get_widget(pGladeWidgets, "controlmode")), gtk_dasher_control_get_parameter_bool( GTK_DASHER_CONTROL(pDasherWidget), BP_CONTROL_MODE));
-  gtk_check_menu_item_set_active( GTK_CHECK_MENU_ITEM(glade_xml_get_widget(pGladeWidgets, "keyboardmode")), get_app_parameter_bool(APP_BP_KEYBOARD_MODE));
-
   switch(gtk_dasher_control_get_parameter_long( GTK_DASHER_CONTROL(pDasherWidget), LP_DASHER_FONTSIZE)) {
   case 1:
     gtk_check_menu_item_set_active( GTK_CHECK_MENU_ITEM(glade_xml_get_widget(pGladeWidgets, "fontsizenormal")), true);
@@ -54,10 +46,12 @@ extern "C" void select_save_file_as(GtkWidget * widget, gpointer user_data);
 extern "C" void select_new_file(GtkWidget *widget, gpointer user_data) {
   //FIXME - confirm this. We should check whether the user wants to lose their work.
 
-  choose_filename();
-  clear_edit();
+  // TODO: Should just call a 'new' method in DasherEditor
+  dasher_editor_generate_filename(g_pEditor);
+  dasher_editor_clear(g_pEditor, false);
+
   //  gtk_dasher_control_set_context(GTK_DASHER_CONTROL(pDasherWidget), "");
-  gtk_dasher_control_invalidate_context(GTK_DASHER_CONTROL(pDasherWidget));
+  gtk_dasher_control_invalidate_context(GTK_DASHER_CONTROL(pDasherWidget), true);
 
   // Starting a new file indicates a new user trial in detailed logging
   gtk_dasher_user_log_new_trial(GTK_DASHER_CONTROL(pDasherWidget));
@@ -81,7 +75,7 @@ extern "C" void select_open_file(GtkWidget *widget, gpointer user_data) {
 #else
     char *filename = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(filesel));
 #endif
-    open_file(filename);
+    dasher_editor_open(g_pEditor, filename);
     g_free(filename);
   }
   gtk_widget_destroy(filesel);
@@ -99,7 +93,7 @@ extern "C" void filesel_hide(GtkWidget *widget, gpointer user_data) {
 extern "C" void open_file_from_filesel(GtkWidget *selector2, GtkFileSelection *selector) {
   filename = gtk_file_selection_get_filename(GTK_FILE_SELECTION(selector));
   filesel_hide(GTK_WIDGET(selector->ok_button), NULL);
-  open_file(filename);
+  dasher_editor_open(g_pEditor, filename);
 }
 
 extern "C" void select_open_file(GtkWidget *widget, gpointer user_data) {
@@ -115,7 +109,7 @@ extern "C" void select_open_file(GtkWidget *widget, gpointer user_data) {
 
 extern "C" void save_file(GtkWidget *widget, gpointer user_data) {
   if(filename != NULL) {
-    save_file_as(filename,FALSE); // FIXME - REIMPLEMENT
+    dasher_editor_save_as(g_pEditor, filename,FALSE); // FIXME - REIMPLEMENT
   }
   else {
     select_save_file_as(NULL, NULL);
@@ -137,7 +131,7 @@ extern "C" void select_save_file_as(GtkWidget *widget, gpointer user_data) {
 #else
     char *filename = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(filesel));
 #endif
-    save_file_as(filename,FALSE);
+    dasher_editor_save_as(g_pEditor, filename,FALSE);
     g_free(filename);
   }
   gtk_widget_destroy(filesel);
@@ -147,7 +141,7 @@ extern "C" void select_save_file_as(GtkWidget *widget, gpointer user_data) {
 
 extern "C" void save_file_from_filesel_and_quit(GtkWidget *selector2, GtkFileSelection *selector) {
   filename = gtk_file_selection_get_filename(GTK_FILE_SELECTION(selector));
-  if(save_file_as(filename, FALSE) == false) {
+  if(dasher_editor_save_as(g_pEditor, filename, FALSE) == false) {
 
     // FIXME - do we really just want to fail silently if the save operation fails?
 
@@ -163,7 +157,7 @@ extern "C" void save_file_from_filesel_and_quit(GtkWidget *selector2, GtkFileSel
 extern "C" void save_file_from_filesel(GtkWidget *selector2, GtkFileSelection *selector) {
   filename = gtk_file_selection_get_filename(GTK_FILE_SELECTION(selector));
   filesel_hide(GTK_WIDGET(selector->ok_button), NULL);
-  save_file_as(filename, FALSE);
+  dasher_editor_save_as(g_pEditor, filename, FALSE);
 }
 
 extern "C" void select_save_file_as(GtkWidget *widget, gpointer user_data) {
@@ -195,7 +189,7 @@ extern "C" void select_append_file(GtkWidget *widget, gpointer user_data) {
 #else
     char *filename = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(filesel));
 #endif
-    //    save_file_as(filename,TRUE);// FIXME - REIMPLEMENT
+    //    dasher_editor_save_as(g_pEditor, filename,TRUE);// FIXME - REIMPLEMENT
     g_free(filename);
   }
   gtk_widget_destroy(filesel);
@@ -206,7 +200,7 @@ extern "C" void select_append_file(GtkWidget *widget, gpointer user_data) {
 extern "C" void append_file_from_filesel(GtkWidget *selector2, GtkFileSelection *selector) {
   filename = gtk_file_selection_get_filename(GTK_FILE_SELECTION(selector));
 
-  save_file_as(filename, TRUE);
+  dasher_editor_save_as(g_pEditor, filename, TRUE);
 
   filesel_hide(GTK_WIDGET(selector->ok_button), NULL);
 }
@@ -233,7 +227,11 @@ extern "C" void select_import_file(GtkWidget *widget, gpointer user_data) {
 #endif
 
   if(gtk_dialog_run(GTK_DIALOG(filesel)) == GTK_RESPONSE_ACCEPT) {
+#ifdef GNOME_LIBS
+    char *filename = gtk_file_chooser_get_uri(GTK_FILE_CHOOSER(filesel));
+#else
     char *filename = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(filesel));
+#endif
 
     gtk_dasher_control_train(GTK_DASHER_CONTROL(pDasherWidget), filename);
 
@@ -284,9 +282,8 @@ extern "C" void select_save_file_as_and_quit(GtkWidget *widget, gpointer user_da
 
 extern "C" void save_file_and_quit(GtkWidget *widget, gpointer user_data) {
   if(filename != NULL) {
-    if (save_file_as(filename,FALSE)==true) {
+    if (dasher_editor_save_as(g_pEditor, filename,FALSE)==true) {
     //  exiting=TRUE;
-    SaveWindowState();
     gtk_main_quit();
     } else {
       return;
@@ -294,14 +291,14 @@ extern "C" void save_file_and_quit(GtkWidget *widget, gpointer user_data) {
   }
   else {
     select_save_file_as(NULL, NULL);
-    SaveWindowState();
     gtk_main_quit();
   }
 }
 
 extern "C" bool ask_save_before_exit(GtkWidget *widget, gpointer data) {
   GtkWidget *dialog = NULL;
-  quitting = TRUE;
+
+  dasher_main_save_state(g_pDasherMain);
 
   if(file_modified != FALSE) {
     // Ask whether to save the modified file, insert filename if it exists.
@@ -313,15 +310,13 @@ extern "C" bool ask_save_before_exit(GtkWidget *widget, gpointer data) {
     }
 
     gtk_dialog_add_buttons(GTK_DIALOG(dialog), _("Don't save"), GTK_RESPONSE_REJECT, _("Don't quit"), GTK_RESPONSE_CANCEL, _("Save and quit"), GTK_RESPONSE_ACCEPT, NULL);
+
     switch (gtk_dialog_run(GTK_DIALOG(dialog))) {
     case GTK_RESPONSE_REJECT:
       //      write_to_file(); // FIXME - REIMPLEMENT
-      exiting = TRUE;
-      SaveWindowState();
       gtk_main_quit();
       break;
     case GTK_RESPONSE_CANCEL:
-      quitting = FALSE;
       gtk_widget_destroy(GTK_WIDGET(dialog));
       return true;
       break;
@@ -338,8 +333,6 @@ extern "C" bool ask_save_before_exit(GtkWidget *widget, gpointer data) {
     // FIXME - REIMPLEMENT
 
     //    write_to_file();
-    exiting = TRUE;
-    SaveWindowState();
     gtk_main_quit();
   }
   return false;
@@ -348,25 +341,25 @@ extern "C" bool ask_save_before_exit(GtkWidget *widget, gpointer data) {
 // 'Edit' menu
 
 extern "C" void clipboard_cut(void) {
-  gtk2_clipboard_callback(CLIPBOARD_CUT);       // FIXME - give this a better name
+  dasher_editor_clipboard(g_pEditor, CLIPBOARD_CUT);       // FIXME - give this a better name
 }
 
 extern "C" void clipboard_copy(void) {
-  gtk2_clipboard_callback(CLIPBOARD_COPY);
+  dasher_editor_clipboard(g_pEditor, CLIPBOARD_COPY);
 }
 
 extern "C" void clipboard_paste(void) {
-  gtk2_clipboard_callback(CLIPBOARD_PASTE);
+  dasher_editor_clipboard(g_pEditor, CLIPBOARD_PASTE);
 }
 
 extern "C" void clipboard_copy_all(void) {
-  gtk2_clipboard_callback(CLIPBOARD_COPYALL);
+  dasher_editor_clipboard(g_pEditor, CLIPBOARD_COPYALL);
 }
 
 // Not actually on the menu, but should be?
 
 extern "C" void clipboard_select_all(void) {
-  gtk2_clipboard_callback(CLIPBOARD_SELECTALL);
+  dasher_editor_clipboard(g_pEditor, CLIPBOARD_SELECTALL);
 }
 
 // 'Options' Menu
@@ -390,34 +383,8 @@ extern "C" void set_dasher_fontsize(GtkWidget *widget, gpointer user_data) {
 }
 
 extern "C" void reset_fonts(GtkWidget *widget, gpointer user_data) {
-  //  reset_edit_font();
-
-  reset_parameter(SP_DASHER_FONT);
-  reset_parameter(APP_SP_EDIT_FONT);
-
-  // FIXME - REIMPLEMENT
-
-  //  reset_dasher_font();
-//   dasher_set_parameter_string( STRING_DASHERFONT, DASHERFONT );
-//   dasher_set_parameter_string( STRING_EDITFONT, "Sans 10" );
-//   editfont="Sans 10";
-//   dasherfont=DASHERFONT;
-}
-
-extern "C" void keyboardmode(GtkWidget *widget, gpointer user_data) {
-  // FIXME - REIMPLEMENT
-//   if (textentry==TRUE) {
-//     gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM(glade_xml_get_widget(widgets,"keyboardmode")), true);
-//   } else {
-  set_app_parameter_bool( APP_BP_KEYBOARD_MODE, GTK_CHECK_MENU_ITEM(widget)->active );
-//   }
-}
-
-extern "C" void controlmode(GtkWidget *widget, gpointer user_data) {
-  // FIXME - REIMPLEMENT
-  gtk_dasher_control_set_parameter_bool( GTK_DASHER_CONTROL( pDasherWidget), BP_CONTROL_MODE, GTK_CHECK_MENU_ITEM(widget)->active );
-  //  dasher_start();
-  //  dasher_redraw();
+  dasher_app_settings_reset(g_pDasherAppSettings, SP_DASHER_FONT);
+  dasher_app_settings_reset(g_pDasherAppSettings, APP_SP_EDIT_FONT);
 }
 
 // 'Help' Menu
@@ -453,23 +420,25 @@ extern "C" void about_dasher(GtkWidget *widget, gpointer user_data) {
     NULL
   };
 
-  gtk_show_about_dialog(GTK_WINDOW(window), 
-			"copyright", "Copyright The Dasher Project", 
+  gtk_show_about_dialog(GTK_WINDOW(window),
+			"authors", authors,
 			"comments", _("Dasher is a predictive text entry application"), 
-			"authors", (const char **)authors,
-			"documenters", (const char **)documenters,
-			"translator-credits", _("translator-credits"),
-			"website", "http://www.dasher.org.uk/",
+			"copyright", "Copyright \xC2\xA9 1998-2006 The Dasher Project", 
+			"documenters", documenters,
+			"license", "GPL 2+",
 			"logo-icon-name", "dasher",
-			"version", PACKAGE_VERSION,
+			"translator-credits", _("translator-credits"),
+			"version", VERSION,
+			"website", "http://www.dasher.org.uk/",
+			"wrap-license", true,
 			NULL);
   
 #else
   // EAT UGLY ABOUT BOX, PHILISTINE
-  GtkWidget *label, *button, *about;
+  GtkWidget *label, *button;
   char *tmp;
 
-  about = gtk_dialog_new();
+  GtkWidget *about = gtk_dialog_new();
 
   gtk_dialog_set_has_separator(GTK_DIALOG(about), FALSE);
   gtk_window_set_title(GTK_WINDOW(about), "About Dasher");
@@ -496,8 +465,7 @@ extern "C" void about_dasher(GtkWidget *widget, gpointer user_data) {
 #endif
 }
 
-// FIXME - I think this is never called?
-
+// TODO: Need to hide menu item if GNOME_LIBS not defined
 extern "C" void show_help(GtkWidget *widget, gpointer user_data) {
 #ifdef GNOME_LIBS
   gnome_help_display_desktop(NULL, "dasher", "dasher", NULL, NULL);
