@@ -12,6 +12,7 @@
 #include "../TabletPC/CursorInRange.h"
 #include "../../DasherCore/DasherComponent.h"
 #include "../../DasherCore/DasherTypes.h"
+#include "../KeyboardHelper.h"
 
 namespace Dasher
 {
@@ -64,7 +65,7 @@ public:
 
 	END_MSG_MAP()
 
-	CCanvas(CDasherInterface * DI);
+	CCanvas(CDasherInterface *DI, Dasher::CEventHandler *pEventHandler, CSettingsStore *pSettingsStore);
 	~CCanvas();
 
 	HWND Create(HWND hParent);
@@ -158,8 +159,8 @@ private:
 
   // Input devices:
 
-  Dasher::CDasherMouseInput * m_pMouseInput;
-  Dasher::CSocketInput * m_pSocketInput;
+  //Dasher::CDasherMouseInput * m_pMouseInput;
+  //Dasher::CSocketInput * m_pSocketInput;
 
   Dasher::screenint imousex, imousey;
   UINT MY_TIMER;
@@ -186,6 +187,8 @@ private:
   // Enables tablet pc events
   CCursorInRange m_CursorInRange;
 
+  CKeyboardHelper *m_pKeyboardHelper;
+
 };
 
 #endif /* #ifndef __Canvas_h__ */
