@@ -29,7 +29,7 @@ using namespace WinUTF8;
 
 /////////////////////////////////////////////////////////////////////////////
 
-CEdit::CEdit() : m_FontSize(0), m_FontName(""), FileHandle(INVALID_HANDLE_VALUE), 
+CEdit::CEdit(CAppSettings *pAppSettings) : m_FontSize(0), m_FontName(""), FileHandle(INVALID_HANDLE_VALUE), 
 				m_FilenameGUI(0), threadid(0), targetwindow(0),
 #ifndef DASHER_WINCE
 pVoice(0),
@@ -37,6 +37,8 @@ pVoice(0),
 				textentry(false) 
 {
   
+m_pAppSettings = pAppSettings;
+
   CodePage = GetUserCodePage();
   m_Font = GetCodePageFont(CodePage, 14);
 
@@ -298,7 +300,7 @@ void CEdit::TNew(const Tstring &filename) {
   AppendMode = false;
   Clear();
 
-  m_pDasherInterface->InvalidateContext();
+  m_pDasherInterface->InvalidateContext(true);
 }
 
 bool CEdit::TOpen(const Tstring &filename) {
@@ -457,35 +459,37 @@ void CEdit::SetFont(string Name, long Size) {
 
 void CEdit::SetInterface(Dasher::CDasherInterfaceBase *DasherInterface) {
   CDashEditbox::SetInterface(DasherInterface);
-
-  CodePage = EncodingToCP(m_pDasherInterface->GetAlphabetType());
+// TODO: Reimplement if necessary
+//  CodePage = EncodingToCP(m_pDasherInterface->GetAlphabetType());
   SetFont(m_FontName, m_FontSize);
 
 }
 
 void CEdit::write_to_file() {
-  const string & TrainFile = m_pDasherInterface->GetTrainFile();
-  if(TrainFile == "")
-    return;
-  Tstring TTrainFile;
-  UTF8string_to_wstring(TrainFile, TTrainFile);
+  // TODO: Reimplement if necessary
 
-  HANDLE hFile = CreateFile(TTrainFile.c_str(),
-                            GENERIC_WRITE, 0, NULL, OPEN_ALWAYS, FILE_ATTRIBUTE_NORMAL, 0);
+  //const string & TrainFile = m_pDasherInterface->GetTrainFile();
+  //if(TrainFile == "")
+  //  return;
+  //Tstring TTrainFile;
+  //UTF8string_to_wstring(TrainFile, TTrainFile);
 
-  if(hFile == INVALID_HANDLE_VALUE) {
-    OutputDebugString(TEXT("Can not open file\n"));
-  }
-  else {
-    DWORD NumberOfBytesWritten;
-    SetFilePointer(hFile, 0, NULL, FILE_END);
-    for(unsigned int i = 0; i < m_Output.size(); i++) {
-      WriteFile(hFile, &m_Output[i], 1, &NumberOfBytesWritten, NULL);
-    }
+  //HANDLE hFile = CreateFile(TTrainFile.c_str(),
+  //                          GENERIC_WRITE, 0, NULL, OPEN_ALWAYS, FILE_ATTRIBUTE_NORMAL, 0);
 
-    m_Output = "";
-    CloseHandle(hFile);
-  }
+  //if(hFile == INVALID_HANDLE_VALUE) {
+  //  OutputDebugString(TEXT("Can not open file\n"));
+  //}
+  //else {
+  //  DWORD NumberOfBytesWritten;
+  //  SetFilePointer(hFile, 0, NULL, FILE_END);
+  //  for(unsigned int i = 0; i < m_Output.size(); i++) {
+  //    WriteFile(hFile, &m_Output[i], 1, &NumberOfBytesWritten, NULL);
+  //  }
+
+  //  m_Output = "";
+  //  CloseHandle(hFile);
+  //}
 }
 
 void CEdit::get_new_context(string &str, int max) {
@@ -517,7 +521,8 @@ void CEdit::output(const std::string &sText) {
 
   InsertText(String);
 
-  if(targetwindow != NULL && textentry == true) {
+//  if(targetwindow != NULL && textentry == true) {
+  if(m_pAppSettings->GetLongParameter(APP_LP_STYLE) == 2) {
     const char *DisplayText = sText.c_str();
 #ifdef UNICODE
     if(DisplayText[0] == 0xd && DisplayText[1] == 0xa) {
@@ -600,7 +605,7 @@ void CEdit::Move(int iDirection, int iDist) {
   if(iDirection == EDIT_FORWARDS) {
     switch(iDist) {
     case EDIT_CHAR:
-      if(iStart != iEnd)
+      //if(iStart != iEnd)
         ++iEnd;
       iStart = iEnd;
       break;
@@ -838,14 +843,7 @@ LRESULT CEdit::OnLButtonDown(UINT message, WPARAM wParam, LPARAM lParam, BOOL& b
 
 LRESULT CEdit::OnLButtonUp(UINT message, WPARAM wParam, LPARAM lParam, BOOL& bHandled)
 {
-    // This doesn't seem to work...
-    // if we click the mouse in the edit control, update the Dasher display
-
-	// DJW20060101 - I put the following line back in, and it half-works
-	// The Dasher display resets to the root context, rather than pulling the
-	// context from the edit control
-	m_pDasherInterface->ChangeEdit();
-    InvalidateRect(NULL, FALSE);
+  m_pDasherInterface->InvalidateContext(false);
 
 	bHandled = FALSE; // let the EDIT class handle it
 	return 0;
@@ -954,7 +952,9 @@ void CEdit::deletetext(const std::string &sText) {
   // newline pair, but we're now assuming we'll never have two real characters for
   // a single symbol
 
-  if(targetwindow != NULL && textentry == true) {
+//  if(targetwindow != NULL && textentry == true) {
+if(m_pAppSettings->GetLongParameter(APP_LP_STYLE) == 2) {
+
 #ifdef _UNICODE
     fakekey[0].type = fakekey[1].type = INPUT_KEYBOARD;
     fakekey[0].ki.wVk = fakekey[1].ki.wVk = VK_BACK;
@@ -1148,6 +1148,13 @@ void CEdit::outputcontrol(void *pointer, int data, int type) {
 
 void CEdit::speak(int what) {
 
+  if(!m_pAppSettings->GetBoolParameter(APP_BP_SPEECH_MODE))
+    return;
+
+  // TODO: Horrible hack - don't speak in direct entry mode
+  if(m_pAppSettings->GetLongParameter(APP_LP_STYLE) == 2)
+    return;
+
 // Todo - put this in a separate class
 
 #ifndef DASHER_WINCE
